import java.awt.*;
import java.awt.font.*;
import java.awt.geom.*;
import java.text.*;

/**
 * A class that represents a picture.  This class inherits from 
 * SimplePicture and allows the student to add functionality to
 * the Picture class. In JES, many "extra" features are already present,
 * available through OO-notation for the advanced media computation
 * students.
 * 
 * Copyright Georgia Institute of Technology 2004-2005
 * @author Barbara Ericson ericson@cc.gatech.edu
 */
public class Picture extends SimplePicture 
{
  ///////////////////// constructors //////////////////////////////////
  
  /**
   * Constructor that takes no arguments 
   */
  public Picture ()
  {
    /* not needed but use it to show students the implicit call to super()
     * child constructors always call a parent constructor 
     */
    super();  
  }
  
  /**
   * Constructor that takes a file name and creates the picture 
   * @param fileName the name of the file to create the picture from
   */
  public Picture(String fileName)
  {
    // let the parent class handle this fileName
    super(fileName);
  }
  
  /**
   * Constructor that takes the width and height
   * @param width the width of the desired picture
   * @param height the height of the desired picture
   */
  public Picture(int width, int height)
  {
    // let the parent class handle this width and height
    super(width,height);
  }
  
  /**
   * Constructor that takes a picture and creates a 
   * copy of that picture
   */
  public Picture(Picture copyPicture)
  {
    // let the parent class do the copy
    super(copyPicture);
  }
  
  ////////////////////// methods ///////////////////////////////////////
  
  /**
   * Method to return a string with information about this picture.
   * @return a string with information about the picture such as fileName,
   * height and width.
   */
  public String toString()
  {
    String output = "Picture, filename " + getFileName() + 
      " height " + getHeight() 
      + " width " + getWidth();
    return output;
    
  }

/* adding graphics to pictures, for use in JES. (added by alexr, Oct 2006) */

    public void addLine(Color acolor, int x1, int y1, int x2, int y2) {
        Graphics g = this.getBufferedImage().getGraphics();
        g.setColor(acolor);
        g.drawLine(x1 - 1,y1 - 1,x2 - 1,y2 - 1);
    }

    public void addText(Color acolor, int x, int y, String string) {
        Graphics g = this.getBufferedImage().getGraphics();
        g.setColor(acolor);
        g.drawString(string, x - 1, y - 1);
    }

    public void addTextWithStyle(Color acolor, int x, int y, String string, Font style) {
        Graphics g = this.getBufferedImage().getGraphics();
        g.setColor(acolor);
        g.setFont(style);
        g.drawString(string, x - 1, y - 1);
    }

    public void addRect(Color acolor, int x, int y, int w, int h) {
        Graphics g = this.getBufferedImage().getGraphics();
        g.setColor(acolor);
        g.drawRect(x - 1,y - 1,w,h);
    }

    public void addRectFilled(Color acolor, int x, int y, int w, int h) {
        Graphics g = this.getBufferedImage().getGraphics();
        g.setColor(acolor);
        g.fillRect(x - 1,y - 1,w,h);
    }

    public void addOvalFilled(Color acolor, int x, int y, int w, int h) {
        Graphics g = this.getBufferedImage().getGraphics();
        g.setColor(acolor);
        g.fillOval(x - 1,y - 1,w,h);
    }

    public void addOval(Color acolor, int x, int y, int w, int h) {
        Graphics g = this.getBufferedImage().getGraphics();
        g.setColor(acolor);
        g.drawOval(x - 1,y - 1,w,h);
    }

    public void addArcFilled(Color acolor, int x, int y,
    int w, int h, int start, int angle) {

        Graphics g = this.getBufferedImage().getGraphics();
        g.setColor(acolor);
        g.fillArc(x - 1,y - 1,w,h,start,angle);
    }
        
    public void addArc(Color acolor,int x, int y, int w, int h, int start, int angle) {
        Graphics g = this.getBufferedImage().getGraphics();
        g.setColor(acolor);
        g.drawArc(x - 1,y - 1,w,h,start,angle);
    }

} // end of class Picture, put all new methods before this
 
